@@ -1,4 +1,3 @@
-import asyncio
 import dataclasses
 import logging
 import os
@@ -35,13 +34,6 @@ log = logging.getLogger(__name__)
 
 TIMEOUT_SECONDS = 30
 
-# We want to try to avoid race conditions with creating the comment if multiple tests are running in parallel
-github_comment_semaphore = asyncio.Semaphore(1)
-
-# Limit the number of concurrent requests to the CLI and API
-cli_request_semaphore = asyncio.Semaphore(10)
-api_request_semaphore = asyncio.Semaphore(10)
-
 
 @retry(stop=stop_after_attempt(3), wait=wait_random_exponential(multiplier=1, max=30), reraise=True)
 async def post_to_cli_with_retry(
@@ -66,7 +58,7 @@ async def post_to_cli(
     if not cli_server_address:
         raise Exception("CLI server address is not set.")
 
-    async with cli_request_semaphore:
+    async with global_state.test_run_api_semaphore():
         return await post_to_cli_with_retry(
             f"{cli_server_address}{path}",
             json,
@@ -98,7 +90,7 @@ async def post_to_api(
     if not api_key:
         raise ValueError(f"You must set the {AutoblocksEnvVar.API_KEY} environment variable.")
 
-    async with api_request_semaphore:
+    async with global_state.test_run_api_semaphore():
         return await post_to_api_with_retry(
             f"{API_ENDPOINT}{sub_path}{path}",
             api_key,
@@ -173,6 +165,7 @@ async def send_start_grid_search_run(
 
 async def send_start_test_run(
     test_external_id: str,
+    message: Optional[str],
     grid_search_run_group_id: Optional[str],
     grid_search_params_combo: Optional[GridSearchParamsCombo],
 ) -> str:
@@ -190,7 +183,7 @@ async def send_start_test_run(
             "/runs",
             json=dict(
                 testExternalId=test_external_id,
-                message=None,
+                message=message,
                 buildId=AutoblocksEnvVar.CI_TEST_RUN_BUILD_ID.get(),
                 gridSearchRunGroupId=grid_search_run_group_id,
                 gridSearchParamsCombo=grid_search_params_combo,
@@ -225,11 +218,11 @@ async def send_test_case_result(
     run_id: str,
     test_case_ctx: TestCaseContext[TestCaseType],
     output: Any,
-    test_case_duration_ms: float,
+    test_case_duration_ms: Optional[float] = None,
 ) -> str:
     # Revision usage is collected throughout a test case's run
     revision_usage = get_revision_usage()
-
+    dataset_item_id = test_case_ctx.test_case.serialize_dataset_item_id()
     serialized_test_case = serialize_test_case(test_case_ctx.test_case)
     serialized_output = serialize_output(output)
     test_case_revision_usage = [usage.serialize() for usage in revision_usage] if revision_usage else None
@@ -242,6 +235,7 @@ async def send_test_case_result(
                 testExternalId=test_external_id,
                 runId=run_id,
                 testCaseHash=test_case_ctx.hash(),
+                datasetItemId=dataset_item_id,
                 testCaseBody=serialized_test_case,
                 testCaseOutput=serialized_output,
                 testCaseDurationMs=test_case_duration_ms,
@@ -260,6 +254,7 @@ async def send_test_case_result(
             f"/runs/{run_id}/results",
             json=dict(
                 testCaseHash=test_case_ctx.hash(),
+                datasetItemId=dataset_item_id,
                 testCaseDurationMs=test_case_duration_ms,
                 testCaseRevisionUsage=test_case_revision_usage,
             ),
@@ -394,7 +389,7 @@ async def send_github_comment() -> None:
 
     log.info(f"Creating GitHub comment for build '{build_id}'.")
     try:
-        async with github_comment_semaphore:
+        async with global_state.github_comment_semaphore():
             await post_to_api(
                 f"/builds/{build_id}/github-comment",
                 json=dict(githubToken=github_token),
@@ -406,3 +401,9 @@ async def send_github_comment() -> None:
             "https://docs.autoblocks.ai/testing/ci#git-hub-comments-github-actions-permissions",
             exc_info=e,
         )
+
+
+async def send_create_human_review_job(run_id: str, assignee_email_address: str, name: str) -> None:
+    await post_to_api(
+        f"/runs/{run_id}/human-review-job", json=dict(assigneeEmailAddress=assignee_email_address, name=name)
+    )
