@@ -7,7 +7,9 @@ from autoblocks._impl.testing.models import Evaluation
 from autoblocks._impl.testing.models import EvaluationOverride
 from autoblocks._impl.testing.models import EvaluationOverrideComment
 from autoblocks._impl.testing.models import EvaluationOverrideField
+from autoblocks._impl.testing.models import EvaluationWithId
 from autoblocks._impl.testing.models import HumanReviewField
+from autoblocks._impl.testing.models import HumanReviewFieldContentType
 from autoblocks._impl.testing.models import ScoreChoice
 from autoblocks._impl.testing.models import TestCaseConfig
 from autoblocks._impl.testing.models import Threshold
@@ -20,10 +22,12 @@ __all__ = [
     "BaseTestCase",
     "BaseTestEvaluator",
     "Evaluation",
+    "EvaluationWithId",
     "EvaluationOverride",
     "EvaluationOverrideComment",
     "EvaluationOverrideField",
     "HumanReviewField",
+    "HumanReviewFieldContentType",
     "TestCaseConfig",
     "Threshold",
     "TracerEvent",
